==> lightdash_client_python-0.1398.0.tar.gz: lightdash_client_python-0.1398.0/lightdash_client/models/get_explore_response_200.py <==
from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.get_explore_response_200_status import GetExploreResponse200Status
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.explore import Explore


T = TypeVar("T", bound="GetExploreResponse200")


@_attrs_define
class GetExploreResponse200:
    """
    Attributes:
        results (Explore):
        status (GetExploreResponse200Status):
    """

    results: "Explore"
    status: GetExploreResponse200Status
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.explore import Explore

        results = self.results.to_dict()

        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "results": results,
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.explore import Explore

        d = src_dict.copy()
        results = Explore.from_dict(d.pop("results"))

        status = GetExploreResponse200Status(d.pop("status"))

        get_explore_response_200 = cls(
            results=results,
            status=status,
        )

        get_explore_response_200.additional_properties = d
        return get_explore_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.1471.0.tar.gz: lightdash_client_python-0.1471.0/lightdash_client/models/get_explore_response_200.py <==
from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.get_explore_response_200_status import GetExploreResponse200Status
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.pick_explore_exclude_keyof_explore_unfiltered_tables import (
        PickExploreExcludeKeyofExploreUnfilteredTables,
    )


T = TypeVar("T", bound="GetExploreResponse200")


@_attrs_define
class GetExploreResponse200:
    """
    Attributes:
        results (PickExploreExcludeKeyofExploreUnfilteredTables): From T, pick a set of properties whose keys are in the
            union K
        status (GetExploreResponse200Status):
    """

    results: "PickExploreExcludeKeyofExploreUnfilteredTables"
    status: GetExploreResponse200Status
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.pick_explore_exclude_keyof_explore_unfiltered_tables import (
            PickExploreExcludeKeyofExploreUnfilteredTables,
        )

        results = self.results.to_dict()

        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "results": results,
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.pick_explore_exclude_keyof_explore_unfiltered_tables import (
            PickExploreExcludeKeyofExploreUnfilteredTables,
        )

        d = src_dict.copy()
        results = PickExploreExcludeKeyofExploreUnfilteredTables.from_dict(d.pop("results"))

        status = GetExploreResponse200Status(d.pop("status"))

        get_explore_response_200 = cls(
            results=results,
            status=status,
        )

        get_explore_response_200.additional_properties = d
        return get_explore_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
